<?php

class Image {

	var $ID;
	var $details;


	function __construct($data) {
		global $wpdb;
		
		if (is_array($data)) {
			$data = (Object) $data;
		}
		
		if (is_object($data)) {
			$this->ID = $data->ID;
			$this->details = $data;
		} else {
			if (is_numeric($data)) {
				$this->ID = $data;
				$this->details = get_post($this->ID);
			} else {
				$pi = pathinfo($data);
				$file = $wpdb->get_row('SELECT * FROM wp_posts WHERE guid LIKE "%'.$data.'"');
				if (!empty($file)) {
					$this->ID = $file->ID;
					$this->details = $file;
				}
			}
		}
	}

	function __get($field) {
		switch ($field) {
			case 'thumb':
				return wp_get_attachment_thumb_url( $this->ID );
				
			case 'thumbs':
				$thumbs = get_children('post_type=attachment&post_mime_type=image&post_parent=' . $this->ID );
				foreach ($thumbs as $id => $thumb) {
					$thumbs[$id] = wp_get_attachment_thumb_url($id);
				}
				return $thumbs;

			case 'full':
				return wp_get_attachment_url( $this->ID );
				
			case 'data':
				return wp_get_attachment_metadata($this->ID);
				
			case 'dimensions':
				$details = wp_get_attachment_image_src($this->ID,'full');
				return $details[1].' x '.$details[2].' pixels';
				
			case 'type':
				$mime = explode('/',$this->post_mime_type);
				return count($mime) > 1? strtoupper($mime[1]) : '';
				
			case 'size':
				return fileSizeString(filesize( get_attached_file( $this->ID ) ));
				
			case 'uuid':
				return get_post_meta($this->ID,'uuid',true);

			default:
				if (property_exists($this->details,$field)) {
					return $this->details->$field;
				}
				trigger_error ('Field '.$field.' not found on Image');
		}

	}
	
	static function getByUUID($uuid) {
		$query = new WP_Query(array(
			'post_type' => 'attachment',
			'post_status' => 'inherit',
			'meta_query' => array(
				array(
					'key' => 'uuid',
					'value' => $uuid,
					'compare' => '=',
				)
			)
		));
		$posts = $query->get_posts();
		if (!empty($posts)) {
			return new PostType($posts[0]);
		} else {
			return false;
		}
	}	

	function src($width,$height=0,$classes="",$extra='') {
		if (is_string($width)) {
			$details = wp_get_attachment_image_src($this->ID,$width);
		} else {
			if ($width > 0 && $height > 0) {
				$details = wp_get_attachment_image_src($this->ID,'width='.$width.'&height='.$height.'&crop=1');
			} elseif ($height == 0) {
				$details = wp_get_attachment_image_src($this->ID,'width='.$width.'&crop=0');
			} else {
				$details = wp_get_attachment_image_src($this->ID,'height='.$height.'&crop=0');
			}
		}
		$class = $details[1] > $details[2]? 'landscape' : 'portrait';
		$class .= ' '.$classes;
		return '<img src="'.$details[0].'" width="'.$details[1].'" height="'.$details[2].'" class="'.$class.'" '.$extra.'>';
	}
	
	function url($width,$height=0) {
		if (is_string($width)) {
			$details = wp_get_attachment_image_src($this->ID,$width);
		} else {
			if ($width > 0 && $height > 0) {
				$details = wp_get_attachment_image_src($this->ID,'width='.$width.'&height='.$height.'&crop=1');
			} elseif ($height == 0) {
				$details = wp_get_attachment_image_src($this->ID,'width='.$width.'&crop=0');
			} else {
				$details = wp_get_attachment_image_src($this->ID,'height='.$height.'&crop=0');
			}
		}
		return $details[0];
	}

	function dimensions($width,$height=0) {
		if (is_string($width)) {
			$details = wp_get_attachment_image_src($this->ID,$width);
		} else {
			$details = wp_get_attachment_image_src($this->ID,array($width,$height));
		}
		return (object) array('width'=>$details[1],'height'=>$details[2]);
	}

}
?>
