<?php
// Use packaged PODS framework if plugin isn't installed
//add_action( 'init', 'gulf_pods_init', 10 );
function gulf_pods_init() {
	require_once(trailingslashit(ABSPATH).'wp-admin/includes/plugin.php');
	if (!is_plugin_active('pods/init.php') && getGet('plugin') !== 'pods/init.php') {
		add_filter( 'pods_admin_menu', '__return_false' );
		add_filter('plugins_url','gulf_pods_plugins_url',10,3);
		require_once(get_template_directory() . '/vendor/pods/init.php');
	}
}
function gulf_pods_plugins_url($url, $path, $plugin) {
	if (strpos($plugin,'/vendor/pods/init.php') !== false) {
		return get_template_directory_uri().'/vendor/pods/';
	} else {
		return $url;
	}
}


// Check PODS types
add_action( 'admin_init', 'gulf_pods_admin_init');
function gulf_pods_admin_init() {
	if (!class_exists('PodsAPI')) {
		return;
	}
	$api = new PodsAPI();
	
	$gulfpods = gulf_pods();
	foreach ($gulfpods as $podname => $gulfpod) {
		if (!$api->pod_exists(array('name'=>$podname))) {
			$api->save_pod($gulfpod['details']);
		}
		$pod = $api->load_pod($podname);
		if (false && $gulfpod['type'] == 'new') {
			$gulfpod['details']['id'] = $pod['id'];
			$gulfpod['details']['fields'] = $pod['fields'];
			$api->save_pod($gulfpod['details']);
			$pod = $api->load_pod($podname);
//			print_r($pod);
		}
		
		$podconfig = array(
			'pod_id' => $pod['id'],
			'pod' => $pod['name'],
		);
	
		foreach ($gulfpod['fields'] as $name => $config) {
			$config = array_merge($config,$podconfig);
			if (!$api->field_exists(array('pod_id'=>$pod['id'],'name'=>$name))) {
				$api->save_field($config);
			} else {
				$field = $api->load_field(array('pod_id'=>$pod['id'],'pod'=>$pod['name'],'name'=>$name));
				$config = array_merge($config,array('id'=>$field['id']));
			}
		}
	}
	


	

}


// Add extra fields
add_action( 'init', 'add_pods_init', 12 );
function add_pods_init() {
	if (defined('PODS_DIR')) {
		require_once(__DIR__. '/geolocation.pods.php');
	}
}

add_filter('pods_api_field_types','add_pods_field_types');
function add_pods_field_types($types) {
	// Add field types to pod setup
	$types[] = 'geolocation';
	return $types;
}


// To fix {{icon}} issue
add_filter('clean_url','fix_icon_file_upload_issue',10,3);
function fix_icon_file_upload_issue($good_protocol_url, $original_url, $_context ) {
	if (substr($original_url,0,1) == '{') { // To fix {{icon}} issue
		$good_protocol_url = $original_url; 
	}
	return $good_protocol_url;
}



function gulf_pods() {
	return array(
		// PAGE
		'page' => array(
			'type' => 'extended',
			'details' => array(
				'name' => 'page',
				'label' => 'Page',
				'type' => 'post_type',
				'storage' => 'meta',
				'object' => 'page',
			),
			'fields' => array(
				'masthead' => array(
					'name' => 'masthead',
					'label' => 'Masthead',
					'type' => 'file',
					'options' => array(
						'file_format_type' => 'multi',
						'file_uploader' => 'attachment',
						'file_attachment_tab' => 'upload',
						'file_edit_title' => 1,
						'file_type' => 'images',
						'file_add_button' => 'Add masthead',
						'file_modal_title' => 'Attach masthead',
						'file_modal_add_button' => 'Add masthead',
					),
				),
				'timeline' => array(
					'name' => 'timeline',
					'label' => 'Timeline',
					'type' => 'pick',
					'pick_object' => 'taxonomy',
					'pick_val' => 'timeline',
					'weight' => 5,
					'options' => array(
						'pick_format_type' => 'single',
						'pick_format_single' => 'dropdown',
					),
				),
			),
		),
		
		// HERO
		'hero' => array(
			'type' => 'new',
			'details' => array(
				'name' => 'hero',
				'label' => 'Heroes',
				'type' => 'post_type',
				'storage' => 'meta',
				'options' => array(
					'label_singular' => 'Hero',
					'show_ui' => true,
					'show_in_menu' => true,
					'capability_type' => 'post',
					'supports_title' => true,
					'supports_editor' => true,
				),
			),
			'fields' => array(
				'image' => array(
					'name' => 'image',
					'label' => 'Image',
					'type' => 'file',
					'options' => array(
						'file_format_type' => 'single',
						'file_uploader' => 'attachment',
						'file_attachment_tab' => 'upload',
						'file_edit_title' => 1,
						'file_type' => 'images',
						'file_add_button' => 'Add image',
						'file_modal_title' => 'Attach image',
						'file_modal_add_button' => 'Add image',
					),
				),
				'link' => array(
					'name' => 'link',
					'label' => 'Link',
					'type' => 'text',
					'options' => array(
					),
				),
				'location' => array(
					'name' => 'location',
					'label' => 'Location',
					'type' => 'pick',
					'options' => array(
						'pick_custom' => implode(PHP_EOL,array('Left','Right','Bottom')),
						'pick_format_type' => 'single',
						'pick_format_single' => 'dropdown',						
					),
				),
				'theme' => array(
					'name' => 'theme',
					'label' => 'Theme',
					'type' => 'pick',
					'options' => array(
						'pick_custom' => implode(PHP_EOL,array('Dark','Light')),
						'pick_format_type' => 'single',
						'pick_format_single' => 'dropdown',						
					),
				),
			),
		),
		
	);

}